@@ -43,7 +43,7 @@ double             _cairo_image_surface_rotate_get_align_angle         (gboolean
 cairo_surface_t *  _cairo_image_surface_rotate                         (cairo_surface_t       *image,
 		    	     	     	     	     	     	        double                 angle,
 		    	     	     	     	     	     	        gboolean               high_quality,
-		    	     	     	     	     	     	        cairo_color_t         *background_color);
+		    	     	     	     	     	     	        GdkRGBA               *background_color);
 
 G_END_DECLS
 
