@@ -493,7 +493,7 @@ gth_location_chooser_realize (GtkWidget *widget)
 
 	GTK_WIDGET_CLASS (gth_location_chooser_parent_class)->realize (widget);
 	self->priv->icon_cache = gth_icon_cache_new (gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (self))),
-						     _gtk_icon_get_pixel_size (GTK_WIDGET (self), GTK_ICON_SIZE_MENU));
+						     _gtk_widget_lookup_for_size (GTK_WIDGET (self), GTK_ICON_SIZE_MENU));
 	entry_points_changed_cb (NULL, self);
 	current_location_changed (self);
 }
